@@ -1,5 +1,5 @@
 package DBIx::Perlish;
-# $Id: Perlish.pm,v 1.74 2007/05/10 10:50:18 tobez Exp $
+# $Id: Perlish.pm,v 1.76 2007/06/22 13:26:20 tobez Exp $
 
 use 5.008;
 use warnings;
@@ -10,7 +10,7 @@ use vars qw($VERSION @EXPORT @EXPORT_OK %EXPORT_TAGS $SQL @BIND_VALUES);
 require Exporter;
 use base 'Exporter';
 
-$VERSION = '0.25';
+$VERSION = '0.26';
 @EXPORT = qw(db_fetch db_select db_update db_delete db_insert sql);
 @EXPORT_OK = qw(union intersect except);
 %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
@@ -227,7 +227,16 @@ sub gen_sql
 				"$tab" :
 				"$tab $S->{tab_alias}->{$tab}";
 	}
-	die "no tables specified in $operation\n" unless keys %tabs;
+	unless (keys %tabs) {
+		if ($operation eq "select" &&
+			$args{flavor} && $args{flavor} eq "oracle" &&
+			$S->{returns})
+		{
+			$tabs{dual} = "dual";
+		} else {
+			die "no tables specified in $operation\n";
+		}
+	}
 	for my $j ( @{$S->{joins}} ) {
 		my ( $join, $tab1, $tab2, $condition) = @$j;
 		$condition = ( defined $condition) ? " on $condition" : '';
@@ -285,7 +294,7 @@ DBIx::Perlish - a perlish interface to SQL databases
 
 =head1 VERSION
 
-This document describes DBIx::Perlish version 0.25
+This document describes DBIx::Perlish version 0.26
 
 
 =head1 SYNOPSIS
@@ -1291,6 +1300,11 @@ a simple C<LIKE> won't suffice.
 The function call C<sysdate()> is transformed into C<sysdate>
 (without parentheses).
 
+Selects without table specification are assumed to be
+selects from DUAL, for example:
+
+    my $newval = db_fetch { return `tab_id_seq.nextval` };
+
 =head3 Postgresql
 
 Native Postgresql regular expressions are used if possible and if
@@ -1356,7 +1370,19 @@ into the standard Perl distribution.
 
 =head1 INCOMPATIBILITIES
 
-None reported.
+If you use C<DBIx::Perlish> together with L<HTML::Mason>,
+you are likely to see warnings "Useless use of ... in void context"
+that Mason helpfully converts into fatal errors.
+
+To fix this, edit your C<handler.pl> and add the following line:
+
+  $ah->interp->ignore_warnings_expr("(?i-xsm:Subroutine .* redefined|Useless use of .+ in void context)");
+
+Here C<$ah> must refer to an instance of C<HTML::Mason::ApacheHandler>
+class.
+
+Mason is to blame for this, since it disregards
+warnings' handlers installed by other modules.
 
 
 =head1 BUGS AND LIMITATIONS
